/**
 * Copyright (C) 2013 Kosmos <contact@kosmos.fr>
 *
 * Projet: blog
 * Version: 1.1-RC-7
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *         http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.kosmos.blog.processus;

import java.util.List;

import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

import com.jsbsoft.jtf.core.InfoBean;
import com.jsbsoft.jtf.core.LangueUtil;
import com.jsbsoft.jtf.exception.ErreurApplicative;
import com.kosmos.blog.om.Articleblog;
import com.kosmos.blog.om.Blog;
import com.kosmos.blog.util.RubriqueUtil;
import com.kportal.extension.module.plugin.rubrique.FichePageAcceuilRubrique.BeanFichePageAccueil;
import com.kportal.extension.module.plugin.rubrique.PageAccueilRubriqueManager;
import com.univ.objetspartages.om.Libelle;
import com.univ.objetspartages.om.Media;
import com.univ.objetspartages.om.Rubrique;
import com.univ.objetspartages.processus.ControleurUniv;
import com.univ.objetspartages.processus.SaisieFiche;
import com.univ.utils.json.CodecJSon;

/**
 * Processus de gestion des blogs.
 */
public class SaisieBlog extends SaisieFiche {

	private static final String ECRAN_RECHERCHE = "RECHERCHE";

	private static final String ECRAN_PRINCIPAL = "PRINCIPAL";

	private static final String ECRAN_CONFIRMATION = "CONFIRMATION";

	private static Logger logger = LoggerFactory.getLogger(SaisieBlog.class);

	private Blog blog = null;

	/**
	 * Constructeur.
	 * 
	 * @param infoBean
	 */
	public SaisieBlog(final InfoBean infoBean) {
		super(infoBean);
	}

	/**
	 * Point d'entree du processus.
	 */
	@Override
	public boolean traiterAction() throws Exception {
		infoBean.set("CODE_OBJET", "9120");
		blog = new Blog();
		blog.setCtx(this);
		blog.init();
		traiterActionParDefaut(blog);
		infoBean.set("NOM_ONGLET", "blog");
		return (etat == FIN);
	}

	/**
	 * Affichage de l'ecran des criteres de recherche d'un(e) blog.
	 */
	@Override
	protected void preparerRECHERCHE() throws Exception {
		ecranLogique = ECRAN_RECHERCHE;
		infoBean.set("LISTE_LANGUES", LangueUtil.getListeLangues());
		infoBean.set("LISTE_THEMATIQUES", Libelle.getListe(this, "04", LangueUtil.getDefaultLocale()));
	}

	/**
	 * Affichage de l'ecran de saisie d'un(e) blog.
	 */
	@Override
	protected void preparerPRINCIPAL() throws Exception {
		ecranLogique = ECRAN_PRINCIPAL;
		infoBean.set("ID_BLOG", blog.getIdBlog().toString());
		infoBean.set("TITRE", blog.getTitre());
		infoBean.set("DESCRIPTION", blog.getDescription());
		infoBean.set("THEMATIQUE", blog.getThematique());
		infoBean.set("LIBELLE_THEMATIQUE", blog.getLibelleThematique());
		infoBean.set("LISTE_THEMATIQUES", Libelle.getListe(this, "04", LangueUtil.getDefaultLocale()));
		if (blog.getArchivage() == null || blog.getArchivage().length() == 0) {
			infoBean.set("ARCHIVAGE", "0");
		} else {
			infoBean.set("ARCHIVAGE", blog.getArchivage());
		}
		infoBean.set("CODE_RUBRIQUE", blog.getCodeRubrique());
		infoBean.set("LIBELLE_CODE_RUBRIQUE", blog.getInfosRubrique().getLibelleAffichable());
		infoBean.set("CODE_RATTACHEMENT", blog.getCodeRattachement());
		infoBean.set("LIBELLE_CODE_RATTACHEMENT", blog.getInfosStructure().getLibelleAffichable());
		infoBean.set("LIBELLE_AFFICHABLE", blog.getLibelleAffichable());
		if (infoBean.get("SAISIE_FRONT") == null) {
			infoBean.set("SOUS_ONGLET", "PRINCIPAL"); // onglet par defaut
		}
		final List<Articleblog> billets = blog.getArticles(this);
		if (billets != null && !billets.isEmpty()) {
			infoBean.set("ARTICLES", billets);
		}
		final Rubrique rubriqueBlog = Rubrique.getFicheRubrique(this, blog.getCode(), blog.getLangue());
		if (rubriqueBlog != null && rubriqueBlog.getIdBandeau() != null) {
			infoBean.set("ID_BANDEAU", rubriqueBlog.getIdBandeau().toString());
		}
		infoBean.set("LISTE_BANDEAUX", Media.getListePhotoParType(this, "0100"));
		ControleurUniv.preparerPRINCIPAL(infoBean, blog, this);
	}

	/**
	 * Traite l'ecran de saisie d'une fiche.
	 */
	@Override
	protected void traiterPRINCIPAL() throws Exception {
		// chargement de l'objet
		if (infoBean.getEtatObjet().equals(InfoBean.ETAT_OBJET_CREATION)) {
			blog.init();
		} else {
			blog.setIdBlog(new Long(infoBean.getString("ID_BLOG")));
			blog.retrieve();
		}
		// changement d'onglet
		if (action.equals(InfoBean.ACTION_ONGLET)) {
			infoBean.set("SOUS_ONGLET", infoBean.getString("SOUS_ONGLET_DEMANDE"));
		}
		// validation de l'ecran
		else if (action.equals(InfoBean.ACTION_ENREGISTRER)) {
			if (StringUtils.isEmpty((String) infoBean.get("CODE_RUBRIQUE"))) {
				throw new ErreurApplicative("La rubrique du blog est obligatoire");
			}
			alimenteDonneesCreation(blog, false);
			blog.setTitre((String) infoBean.get("TITRE"));
			blog.setDescription((String) infoBean.get("DESCRIPTION"));
			blog.setThematique((String) infoBean.get("THEMATIQUE"));
			blog.setArchivage((String) infoBean.get("ARCHIVAGE"));
			blog.setCodeRubrique((String) infoBean.get("CODE_RUBRIQUE"));
			Long idBandeau = null;
			if (infoBean.get("ID_BANDEAU") != null && ((String) infoBean.get("ID_BANDEAU")).length() > 0) {
				idBandeau = Long.valueOf((String) infoBean.get("ID_BANDEAU"));
			}
			final String rubriqueBlogCode = blog.getCode();
			if (!RubriqueUtil.exists(rubriqueBlogCode) || StringUtils.isBlank(rubriqueBlogCode)) {
				logger.debug("- rubrique de blog absente : création à la volée...");
				final Rubrique rubriqueBlog = new Rubrique();
				rubriqueBlog.setCtx(this);
				rubriqueBlog.init();
				if (StringUtils.isBlank(rubriqueBlogCode)) {
					final String timeStamp = Long.toString(System.currentTimeMillis());
					rubriqueBlog.setCode(timeStamp.substring(timeStamp.length() - 8, timeStamp.length()));
				} else {
					rubriqueBlog.setCode(rubriqueBlogCode);
				}
				rubriqueBlog.setIntitule("Blog [" + blog.getTitre() + "]");
				rubriqueBlog.setNomOnglet(blog.getTitre());
				rubriqueBlog.setCategorie("HIDDEN");
				rubriqueBlog.setCodeRubriqueMere(blog.getCodeRubrique());
				if (idBandeau != null) {
					rubriqueBlog.setIdBandeau(idBandeau);
				}
				final BeanFichePageAccueil beanFichePageTete = new BeanFichePageAccueil();
				beanFichePageTete.setCode(blog.getCode());
				beanFichePageTete.setLangue(blog.getLangue());
				beanFichePageTete.setObjet("blog");
				rubriqueBlog.setPageAccueil(CodecJSon.encodeObjectToJSonInString(beanFichePageTete));
				rubriqueBlog.setTypeRubrique(PageAccueilRubriqueManager.getInstance().getTypePageAcceuilParBeanPageAccueil(beanFichePageTete));
				rubriqueBlog.add();
				logger.debug("- rubrique de blog créée");
				Rubrique.rechargement();
			} else {
				final Rubrique rubriqueBlog = Rubrique.getFicheRubrique(this, blog.getCode(), blog.getLangue());
				if (rubriqueBlog != null && idBandeau != null) {
					rubriqueBlog.setIdBandeau(idBandeau);
				}
			}
			logger.debug("< ACTION_ENREGISTRER : rubrique de blog OK");
		}
		ecranLogique = ControleurUniv.traiterPRINCIPAL(infoBean, blog, this);
		if (infoBean.get("SAISIE_FRONT") != null) {
			ecranLogique = ECRAN_CONFIRMATION;
		}
		if (ecranLogique.length() == 0) {
			etat = FIN;
		}
	}
}
